@@ -31,20 +31,14 @@ describe 'horizon' do
           )
       }
       it { is_expected.to contain_exec('refresh_horizon_django_cache').with({
-          :command     => '/usr/share/openstack-dashboard/manage.py collectstatic --noinput --clear',
-          :refreshonly => true,
-      })}
-      it { is_expected.to contain_exec('refresh_horizon_django_compress').with({
-          :command     => '/usr/share/openstack-dashboard/manage.py compress --force',
+          :command     => '/usr/share/openstack-dashboard/manage.py collectstatic --noinput --clear && /usr/share/openstack-dashboard/manage.py compress --force',
           :refreshonly => true,
       })}
       it {
         if facts[:os_package_type] == 'rpm'
           is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]')
-          is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]')
         else
           is_expected.to_not contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]')
-          is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]')
         end
       }
 
@@ -112,19 +106,22 @@ describe 'horizon' do
           :compress_offline             => false,
           :hypervisor_options           => {'can_set_mount_point' => false, 'can_set_password' => true },
           :cinder_options               => {'enable_backup' => true },
-          :keystone_options             => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
           :neutron_options              => {'enable_lb' => true, 'enable_firewall' => true, 'enable_quotas' => false, 'enable_security_group' => false, 'enable_vpn' => true,
                                             'enable_distributed_router' => false, 'enable_ha_router' => false, 'profile_support' => 'cisco',
                                             'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
           :file_upload_temp_dir         => '/var/spool/horizon',
           :secure_cookies               => true,
-          :custom_theme_path            => 'static/themes/green',
           :api_versions                 => {'identity' => 2.0},
           :keystone_multidomain_support => true,
           :keystone_default_domain      => 'domain.tld',
           :overview_days_range          => 1,
           :session_timeout              => 1800,
           :timezone                     => 'Asia/Shanghai',
+          :available_themes             => [
+            { 'name' => 'default', 'label' => 'Default', 'path' => 'themes/default' },
+            { 'name' => 'material', 'label' => 'Material', 'path' => 'themes/material' },
+          ],
+          :default_theme                => 'default'
         })
       end
 
@@ -147,14 +144,6 @@ describe 'horizon' do
           'OPENSTACK_KEYSTONE_URL = "https://keystone.example.com:4682"',
           'OPENSTACK_KEYSTONE_DEFAULT_ROLE = "SwiftOperator"',
           'OPENSTACK_SSL_NO_VERIFY = True',
-          "OPENSTACK_KEYSTONE_BACKEND = {",
-          "    'name': 'native',",
-          "    'can_edit_user': True,",
-          "    'can_edit_group': True,",
-          "    'can_edit_project': True,",
-          "    'can_edit_domain': False,",
-          "    'can_edit_role': False,",
-          "}",
           "    'can_set_mount_point': False,",
           "    'can_set_password': True,",
           "    'enable_backup': True,",
@@ -171,7 +160,11 @@ describe 'horizon' do
           'SECONDARY_ENDPOINT_TYPE = "ANY-VALUE"',
           'API_RESULT_LIMIT = 4682',
           'TIME_ZONE = "Asia/Shanghai"',
-          "CUSTOM_THEME_PATH = 'static/themes/green'",
+          "AVAILABLE_THEMES = [",
+          "  ('default', 'Default', 'themes/default'),",
+          "  ('material', 'Material', 'themes/material'),",
+          "]",
+          "DEFAULT_THEME = 'default'",
           "            'level': 'DEBUG',",
           "            'handlers': ['syslog'],",
           "SESSION_TIMEOUT = 1800",
@@ -182,7 +175,6 @@ describe 'horizon' do
       end
 
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]') }
-      it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]') }
 
       it { is_expected.to contain_file(params[:file_upload_temp_dir]) }
     end
@@ -201,7 +193,6 @@ describe 'horizon' do
       end
 
       it { is_expected.to contain_exec('refresh_horizon_django_cache') }
-      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
     context 'installs python memcache library when cache_backend is set to memcache' do
@@ -214,39 +205,11 @@ describe 'horizon' do
       it {
         is_expected.to contain_package('python-memcache').with(
           :ensure => 'present',
-          :tag    => ['openstack']
+          :tag    => ['openstack', 'horizon-package']
          )
       }
     end
 
-    context 'with tuskar-ui enabled' do
-      before do
-        params.merge!({
-          :tuskar_ui => true,
-          :tuskar_ui_ironic_discoverd_url      => 'http://127.0.0.1:5050',
-          :tuskar_ui_undercloud_admin_password => 'somesecretpassword',
-          :tuskar_ui_deployment_mode           => 'scale',
-        })
-      end
-
-      it 'generates local_settings.py' do
-        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-          'IRONIC_DISCOVERD_URL = "http://127.0.0.1:5050"',
-          'UNDERCLOUD_ADMIN_PASSWORD = "somesecretpassword"',
-          'DEPLOYMENT_MODE = "scale"',
-        ])
-      end
-    end
-
-    context 'with wrong tuskar_ui_deployment_mode parameter value' do
-      before do
-        params.merge!({
-          :tuskar_ui_deployment_mode => 'wrong' })
-      end
-      it_raises 'a Puppet::Error', /'wrong' is not correct value for tuskar_ui_deployment_mode parameter. It must be either 'scale' or 'poc'./
-    end
-
-
     context 'with vhost_extra_params' do
       before do
         params.merge!({
@@ -431,38 +394,6 @@ describe 'horizon' do
         ])
       end
     end
-
-    context 'with websso enabled' do
-      before do
-        params.merge!({
-                        :websso_enabled => 'True',
-                        :websso_initial_choice => 'acme',
-                        :websso_choices => [
-                          ['oidc', 'OpenID Connect'],
-                          ['saml2', 'Security Assertion Markup Language'],
-                        ],
-                        :websso_idp_mapping => {
-                          'acme_oidc'  => ['acme', 'oidc'],
-                          'acme_saml2' => ['acme', 'saml2'],
-                        }
-                      })
-      end
-      it 'configures websso options' do
-        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-                                          'WEBSSO_ENABLED = True',
-                                          'WEBSSO_INITIAL_CHOICE = "acme"',
-                                          'WEBSSO_CHOICES = (',
-                                          '    ("credentials", _("Keystone Credentials")),',
-                                          '    ("oidc", _("OpenID Connect")),',
-                                          '    ("saml2", _("Security Assertion Markup Language")),',
-                                          ')',
-                                          'WEBSSO_IDP_MAPPING = {',
-                                          '    "acme_oidc": ("acme", "oidc"),',
-                                          '    "acme_saml2": ("acme", "saml2"),',
-                                          '}',
-                                        ])
-      end
-    end
   end
 
   context 'on RedHat platforms' do
